==> apache-kylin-3.1.3-source-release.zip: apache-kylin-3.1.3/tool/src/main/java/org/apache/kylin/tool/metrics/systemcube/streamingv2/KafkaTopicCreator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kylin.tool.metrics.systemcube.streamingv2;

import org.apache.kylin.common.KylinConfig;
import org.apache.kylin.metrics.lib.impl.kafka.KafkaReservoirReporter;

public class KafkaTopicCreator {

    public static String generateCreateCommand(KylinConfig config) {
        StringBuilder sb = new StringBuilder();
        String[] topics = new String[]{
                config.getKylinMetricsSubjectQuery(),
                config.getKylinMetricsSubjectQueryCube(),
                config.getKylinMetricsSubjectQueryRpcCall(),
                config.getKylinMetricsSubjectJob(),
                config.getKylinMetricsSubjectJobException()};
        for (String topic : topics) {
            String finalTopic = KafkaReservoirReporter.decorateTopic(topic);
            sb.append("sh kafka-topics");
            sb.append(" --create");
            sb.append(" --topic ");
            sb.append(finalTopic);
            sb.append(" --zookeeper localhost:2181");
            sb.append(" --partitions 3");
            sb.append(" --replication-factor 1");
            sb.append(" \n");
        }
        return sb.toString();
    }
}

==> apache-kylin-4.0.4-source-release.zip: apache-kylin-4.0.4/tool/src/main/java/org/apache/kylin/tool/metrics/systemcube/streamingv2/KafkaTopicCreator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kylin.tool.metrics.systemcube.streamingv2;

import org.apache.kylin.common.KylinConfig;
import org.apache.kylin.metrics.lib.impl.kafka.KafkaReservoirReporter;

public class KafkaTopicCreator {

    public static String generateCreateCommand(KylinConfig config) {
        StringBuilder sb = new StringBuilder();
        String[] topics = new String[]{
                config.getKylinMetricsSubjectQueryExecution(),
                config.getKylinMetricsSubjectQuerySparkJob(),
                config.getKylinMetricsSubjectQuerySparkStage(),
                config.getKylinMetricsSubjectJob(),
                config.getKylinMetricsSubjectJobException()};
        for (String topic : topics) {
            String finalTopic = KafkaReservoirReporter.decorateTopic(topic);
            sb.append("sh kafka-topics");
            sb.append(" --create");
            sb.append(" --topic ");
            sb.append(finalTopic);
            sb.append(" --zookeeper localhost:2181");
            sb.append(" --partitions 3");
            sb.append(" --replication-factor 1");
            sb.append(" \n");
        }
        return sb.toString();
    }
}
